FlyFlexUtils class

Utility class for handling Tailwind-like flex logic

Constructors

FlyFlexUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

apply(BuildContext context, FlyStyle style, Widget child) → Widget
Applies flex properties to a widget
hasFlexProperties(FlyStyle style) → bool
Check if any flex properties are set
resolveFlex(BuildContext context, FlyStyle style) → int?
Resolves flex value from FlyStyle
resolveFlexBasis(BuildContext context, FlyStyle style) → double?
Resolves flex basis value from FlyStyle
resolveFlexFit(BuildContext context, FlyStyle style) → FlexFit
Resolves FlexFit from flex value
resolveFlexGrow(BuildContext context, FlyStyle style) → int?
Resolves flex grow value from FlyStyle
resolveFlexShrink(BuildContext context, FlyStyle style) → int?
Resolves flex shrink value from FlyStyle