FlyPosition<T> mixin

Mixin that provides Tailwind-like position methods for any widget

Mixin applications

Properties

copyWith → T Function(FlyStyle newStyle)
no setter
flyStyle → FlyStyle
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasPositionProperties → bool
Check if any position properties are set
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyPosition(BuildContext context, Widget child) → Widget
Apply position properties to a widget
bottom(dynamic value) → T
Set bottom position - accepts int, double, or String (token name like 's2', 's4', etc.)
inset(dynamic value) → T
Set inset (all sides) - accepts int, double, or String (token name like 's2', 's4', etc.)
insetX(dynamic value) → T
Set insetX (left and right) - accepts int, double, or String (token name like 's2', 's4', etc.)
insetY(dynamic value) → T
Set insetY (top and bottom) - accepts int, double, or String (token name like 's2', 's4', etc.)
left(dynamic value) → T
Set left position - accepts int, double, or String (token name like 's2', 's4', etc.)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Set right position - accepts int, double, or String (token name like 's2', 's4', etc.)
top(dynamic value) → T
Set top position - accepts int, double, or String (token name like 's2', 's4', etc.)
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited