FlyPositionUtils class

Utility class for handling Tailwind-like position logic

Constructors

FlyPositionUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

apply(BuildContext context, FlyStyle style, Widget child) → Widget
Applies position properties to a widget
hasPositionProperties(FlyStyle style) → bool
Check if any position properties are set
resolveInset(BuildContext context, FlyStyle style) → double?
Resolves inset value from FlyStyle
resolveInsetX(BuildContext context, FlyStyle style) → double?
Resolves insetX value from FlyStyle
resolveInsetY(BuildContext context, FlyStyle style) → double?
Resolves insetY value from FlyStyle
resolvePosition(BuildContext context, FlyStyle style, String property) → double?
Resolves position value from FlyStyle