FlyTextColor<T> mixin

Mixin that provides text color methods for text widgets

Mixin applications

Properties

copyWith → T Function(FlyStyle newStyle)
no setter
flyStyle FlyStyle
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

color(dynamic value) → T
Set text color - accepts Color object or String (token name/hex)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited