FlyIcon class

A builder-style widget that mimics Tailwind-like utilities for icons

Inheritance
Mixed-in types

Constructors

FlyIcon(dynamic icon, {Key? key, double? iconSize, Color? iconColor, String? semanticLabel, TextDirection? textDirection, FlyStyle flyStyle = const FlyStyle()})

Properties

copyWith → FlyIcon Function(FlyStyle newStyle)
no setteroverride
flyStyle → FlyStyle
no setteroverride
hasFlexProperties → bool
Check if any flex properties are set
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasPositionProperties → bool
Check if any position properties are set
no setterinherited
icon → dynamic
final
iconColor → Color?
final
iconSize → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel → String?
final
textDirection → TextDirection?
final

Methods

applyFlex(BuildContext context, Widget child) → Widget
Apply flex properties to a widget
inherited
applyMargin(BuildContext context, Widget child) → Widget
Applies margin to a widget using the resolved EdgeInsets
inherited
applyPadding(BuildContext context, Widget child) → Widget
Applies padding to a widget using the resolved EdgeInsets
inherited
applyPosition(BuildContext context, Widget child) → Widget
Apply position properties to a widget
inherited
applySize(BuildContext context, Widget child) → Widget
Applies size constraints to a widget using the resolved values
inherited
basis(String value) → FlyIcon
Set flex basis - accepts String ('s32', 's40', 's48', etc.) This method can be chained with other flex methods, with later calls overriding earlier ones
inherited
bottom(dynamic value) → FlyIcon
Set bottom position - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
color(dynamic value) → FlyIcon
Set text color - accepts Color object or String (token name/hex)
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
flex(dynamic value) → FlyIcon
Set flex value - accepts int (1-12) or String ('auto', 'initial', 'none') This method can be chained with other flex methods, with later calls overriding earlier ones
inherited
getDefaultStyle(FlyStyle incomingStyle) → FlyStyle
Override this to provide component-specific default styles The incoming flyStyle will be merged with these defaults
grow(int value) → FlyIcon
Set flex grow - accepts int (0-2) This method can be chained with other flex methods, with later calls overriding earlier ones
inherited
h(dynamic value) → FlyIcon
Set height - accepts int, double, or String (token name/unit)
inherited
inset(dynamic value) → FlyIcon
Set inset (all sides) - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
insetX(dynamic value) → FlyIcon
Set insetX (left and right) - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
insetY(dynamic value) → FlyIcon
Set insetY (top and bottom) - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
left(dynamic value) → FlyIcon
Set left position - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
m(dynamic value) → FlyIcon
Set uniform margin - accepts int, double, or String (token name/unit)
inherited
maxH(dynamic value) → FlyIcon
Set max height - accepts int, double, or String (token name/unit)
inherited
maxW(dynamic value) → FlyIcon
Set max width - accepts int, double, or String (token name/unit)
inherited
mb(dynamic value) → FlyIcon
Set bottom margin - accepts int, double, or String (token name/unit)
inherited
minH(dynamic value) → FlyIcon
Set min height - accepts int, double, or String (token name/unit)
inherited
minW(dynamic value) → FlyIcon
Set min width - accepts int, double, or String (token name/unit)
inherited
ml(dynamic value) → FlyIcon
Set left margin - accepts int, double, or String (token name/unit)
inherited
mr(dynamic value) → FlyIcon
Set right margin - accepts int, double, or String (token name/unit)
inherited
mt(dynamic value) → FlyIcon
Set top margin - accepts int, double, or String (token name/unit)
inherited
mx(dynamic value) → FlyIcon
Set horizontal margin (left + right) - accepts int, double, or String (token name/unit)
inherited
my(dynamic value) → FlyIcon
Set vertical margin (top + bottom) - accepts int, double, or String (token name/unit)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
p(dynamic value) → FlyIcon
Set uniform padding - accepts int, double, or String (token name/unit)
inherited
pb(dynamic value) → FlyIcon
Set bottom padding - accepts int, double, or String (token name/unit)
inherited
pl(dynamic value) → FlyIcon
Set left padding - accepts int, double, or String (token name/unit)
inherited
pr(dynamic value) → FlyIcon
Set right padding - accepts int, double, or String (token name/unit)
inherited
pt(dynamic value) → FlyIcon
Set top padding - accepts int, double, or String (token name/unit)
inherited
px(dynamic value) → FlyIcon
Set horizontal padding (left + right) - accepts int, double, or String (token name/unit)
inherited
py(dynamic value) → FlyIcon
Set vertical padding (top + bottom) - accepts int, double, or String (token name/unit)
inherited
resolveHeight(BuildContext context) → double?
Resolves height from FlyStyle and FlyTheme into double
inherited
resolveIntrinsicWidth() → FlyIntrinsicWidth?
Resolves intrinsic width from FlyStyle
inherited
resolveMargin(BuildContext context) → EdgeInsets
Resolves margin from FlyStyle and FlyTheme into EdgeInsets
inherited
resolveMaxHeight(BuildContext context) → double?
Resolves max height from FlyStyle and FlyTheme into double
inherited
resolveMaxWidth(BuildContext context) → double?
Resolves max width from FlyStyle and FlyTheme into double
inherited
resolveMinHeight(BuildContext context) → double?
Resolves min height from FlyStyle and FlyTheme into double
inherited
resolveMinWidth(BuildContext context) → double?
Resolves min width from FlyStyle and FlyTheme into double
inherited
resolvePadding(BuildContext context) → EdgeInsets
Resolves padding from FlyStyle and FlyTheme into EdgeInsets
inherited
resolveWidth(BuildContext context) → double?
Resolves width from FlyStyle and FlyTheme into double
inherited
Set right position - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
shrink(int value) → FlyIcon
Set flex shrink - accepts int (0-1) This method can be chained with other flex methods, with later calls overriding earlier ones
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
top(dynamic value) → FlyIcon
Set top position - accepts int, double, or String (token name like 's2', 's4', etc.)
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
w(dynamic value) → FlyIcon
Set width - accepts int, double, or String (token name/unit)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited