FontConverter class
Font conversion utilities for CSS to Flutter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertFontFamily(
String fontValue) → String - Convert CSS font family to Flutter-compatible format
-
convertFontSize(
String sizeValue) → String - Convert CSS font size to Flutter double
-
convertFontWeight(
String weightValue) → String - Convert CSS font weight to Flutter FontWeight
-
convertLetterSpacing(
String spacingValue) → String - Convert CSS letter spacing to Flutter double
-
convertLineHeight(
String lineHeightValue) → String - Convert CSS line height to Flutter double