FlyTextColor<T> mixin
Mixin that provides text color methods for text widgets
Properties
Methods
-
color(
dynamic value) → T - Set text color - accepts Color object or String (token name/hex)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited